@@ -1,5 +1,7 @@
 from .event import EventResource, EventOwnerResource, EventPricingResource
-from .talk import TalkResource
+from .talk import TalkResource, TalkCounterResource
 from .testimony import TestimonyResource
 from .user import UserResource
 from .visit import VisitResource
+from .contact import ContactUserResource
+from .crush import CrushResource
